aboutsummaryrefslogtreecommitdiffhomepage
path: root/crates/shirabe/src/command/suggests_command.rs
diff options
context:
space:
mode:
Diffstat (limited to 'crates/shirabe/src/command/suggests_command.rs')
-rw-r--r--crates/shirabe/src/command/suggests_command.rs5
1 files changed, 3 insertions, 2 deletions
diff --git a/crates/shirabe/src/command/suggests_command.rs b/crates/shirabe/src/command/suggests_command.rs
index 8166c1e..b4693a2 100644
--- a/crates/shirabe/src/command/suggests_command.rs
+++ b/crates/shirabe/src/command/suggests_command.rs
@@ -90,8 +90,9 @@ impl SuggestsCommand {
}
let installed_repo = InstalledRepository::new(installed_repos);
- // TODO(phase-b): SuggestedPackagesReporter::new expects Box<dyn IOInterface>; self.get_io() returns &mut dyn IOInterface
- let io_box: Box<dyn IOInterface> = todo!("share IOInterface as Box<dyn IOInterface>");
+ // TODO(phase-b): SuggestedPackagesReporter::new expects std::rc::Rc<std::cell::RefCell<dyn IOInterface>>; self.get_io() returns &mut dyn IOInterface
+ let io_box: std::rc::Rc<std::cell::RefCell<dyn IOInterface>> =
+ todo!("share IOInterface as Box<dyn IOInterface>");
let mut reporter = SuggestedPackagesReporter::new(io_box);
let filter = input.get_argument("packages");